package org.apache.bcel.classfile;

import java.io.DataInput;
import java.io.DataOutputStream;
import java.io.IOException;
import java.util.Arrays;

/* loaded from: org_apache_bcel_classfile.jar:org/apache/bcel/classfile/Module.class */
public final class Module extends Attribute {
    private final int moduleNameIndex;
    private final int moduleFlags;
    private final int moduleVersionIndex;
    private ModuleRequires[] requiresTable;
    private ModuleExports[] exportsTable;
    private ModuleOpens[] opensTable;
    private final int usesCount;
    private final int[] usesIndex;
    private ModuleProvides[] providesTable;

    /* JADX INFO: Access modifiers changed from: package-private */
    public Module(int nameIndex, int length, DataInput input, ConstantPool constantPool) throws IOException {
        super((byte) 22, nameIndex, length, constantPool);
        this.moduleNameIndex = input.readUnsignedShort();
        this.moduleFlags = input.readUnsignedShort();
        this.moduleVersionIndex = input.readUnsignedShort();
        int requiresCount = input.readUnsignedShort();
        this.requiresTable = new ModuleRequires[requiresCount];
        for (int i = 0; i < requiresCount; i++) {
            this.requiresTable[i] = new ModuleRequires(input);
        }
        int exportsCount = input.readUnsignedShort();
        this.exportsTable = new ModuleExports[exportsCount];
        for (int i2 = 0; i2 < exportsCount; i2++) {
            this.exportsTable[i2] = new ModuleExports(input);
        }
        int opensCount = input.readUnsignedShort();
        this.opensTable = new ModuleOpens[opensCount];
        for (int i3 = 0; i3 < opensCount; i3++) {
            this.opensTable[i3] = new ModuleOpens(input);
        }
        this.usesCount = input.readUnsignedShort();
        this.usesIndex = new int[this.usesCount];
        for (int i4 = 0; i4 < this.usesCount; i4++) {
            this.usesIndex[i4] = input.readUnsignedShort();
        }
        int providesCount = input.readUnsignedShort();
        this.providesTable = new ModuleProvides[providesCount];
        for (int i5 = 0; i5 < providesCount; i5++) {
            this.providesTable[i5] = new ModuleProvides(input);
        }
    }

    @Override // org.apache.bcel.classfile.Attribute, org.apache.bcel.classfile.Node
    public void accept(Visitor v) {
        v.visitModule(this);
    }

    @Override // org.apache.bcel.classfile.Attribute
    public Attribute copy(ConstantPool constantPool) {
        Module c = (Module) clone();
        c.requiresTable = new ModuleRequires[this.requiresTable.length];
        Arrays.setAll(c.requiresTable, i -> {
            return this.requiresTable[i].copy();
        });
        c.exportsTable = new ModuleExports[this.exportsTable.length];
        Arrays.setAll(c.exportsTable, i2 -> {
            return this.exportsTable[i2].copy();
        });
        c.opensTable = new ModuleOpens[this.opensTable.length];
        Arrays.setAll(c.opensTable, i3 -> {
            return this.opensTable[i3].copy();
        });
        c.providesTable = new ModuleProvides[this.providesTable.length];
        Arrays.setAll(c.providesTable, i4 -> {
            return this.providesTable[i4].copy();
        });
        c.setConstantPool(constantPool);
        return c;
    }

    @Override // org.apache.bcel.classfile.Attribute
    public void dump(DataOutputStream file) throws IOException {
        super.dump(file);
        file.writeShort(this.moduleNameIndex);
        file.writeShort(this.moduleFlags);
        file.writeShort(this.moduleVersionIndex);
        file.writeShort(this.requiresTable.length);
        for (ModuleRequires entry : this.requiresTable) {
            entry.dump(file);
        }
        file.writeShort(this.exportsTable.length);
        for (ModuleExports entry2 : this.exportsTable) {
            entry2.dump(file);
        }
        file.writeShort(this.opensTable.length);
        for (ModuleOpens entry3 : this.opensTable) {
            entry3.dump(file);
        }
        file.writeShort(this.usesIndex.length);
        for (int entry4 : this.usesIndex) {
            file.writeShort(entry4);
        }
        file.writeShort(this.providesTable.length);
        for (ModuleProvides entry5 : this.providesTable) {
            entry5.dump(file);
        }
    }

    public ModuleExports[] getExportsTable() {
        return this.exportsTable;
    }

    public ModuleOpens[] getOpensTable() {
        return this.opensTable;
    }

    public ModuleProvides[] getProvidesTable() {
        return this.providesTable;
    }

    public ModuleRequires[] getRequiresTable() {
        return this.requiresTable;
    }

    @Override // org.apache.bcel.classfile.Attribute
    public String toString() {
        ConstantPool cp = super.getConstantPool();
        StringBuilder buf = new StringBuilder();
        buf.append("Module:\n");
        buf.append("  name:    ").append(Utility.pathToPackage(cp.getConstantString(this.moduleNameIndex, (byte) 19))).append("\n");
        buf.append("  flags:   ").append(String.format("%04x", Integer.valueOf(this.moduleFlags))).append("\n");
        String version = this.moduleVersionIndex == 0 ? "0" : cp.getConstantString(this.moduleVersionIndex, (byte) 1);
        buf.append("  version: ").append(version).append("\n");
        buf.append("  requires(").append(this.requiresTable.length).append("):\n");
        for (ModuleRequires module : this.requiresTable) {
            buf.append("    ").append(module.toString(cp)).append("\n");
        }
        buf.append("  exports(").append(this.exportsTable.length).append("):\n");
        for (ModuleExports module2 : this.exportsTable) {
            buf.append("    ").append(module2.toString(cp)).append("\n");
        }
        buf.append("  opens(").append(this.opensTable.length).append("):\n");
        for (ModuleOpens module3 : this.opensTable) {
            buf.append("    ").append(module3.toString(cp)).append("\n");
        }
        buf.append("  uses(").append(this.usesIndex.length).append("):\n");
        for (int index : this.usesIndex) {
            String className = cp.getConstantString(index, (byte) 7);
            buf.append("    ").append(Utility.compactClassName(className, false)).append("\n");
        }
        buf.append("  provides(").append(this.providesTable.length).append("):\n");
        for (ModuleProvides module4 : this.providesTable) {
            buf.append("    ").append(module4.toString(cp)).append("\n");
        }
        return buf.substring(0, buf.length() - 1);
    }
}
